@@ -175,7 +175,8 @@ sub get_download_infos {
         say "No videos";
         exit;
     }
-    return $opt, $info;
+    #return $opt, $info;
+    return;
 }
 
 
