@@ -8,9 +8,9 @@ use 5.010000;
 use Exporter qw( import );
 our @EXPORT_OK = qw( linefolded_print_info );
 
-use Term::ANSIScreen   qw( :cursor :screen );
-use Term::Choose::Util qw( term_size );
-use Text::LineFold     qw();
+use Term::ANSIScreen       qw( :cursor :screen );
+use Term::Choose::LineFold qw( line_fold );
+use Term::Choose::Util     qw( term_size );
 
 use if $^O eq 'MSWin32', 'Win32::Console::ANSI';
 
@@ -65,8 +65,6 @@ sub linefolded_print_info {
     my ( $maxcols, $maxrows ) = term_size();
     $maxcols -= $opt->{right_margin};
     my $col_max = $maxcols > $opt->{max_info_width} ? $opt->{max_info_width} : $maxcols;
-    my $lf = Text::LineFold->new( %{$opt->{linefold}} );
-    $lf->config( 'ColMax', $col_max );
     my $print_array = [];
     for my $key ( @keys ) {
         next if ! length $info->{$ex}{$video_id}{$key};
@@ -74,7 +72,11 @@ sub linefolded_print_info {
         $info->{$ex}{$video_id}{$key} =~ s/^\s+//;
         ( my $kk = $key ) =~ s/_/ /g;
         my $pr_key = sprintf "%*.*s : ", $key_len, $key_len, $kk;
-        my $text = $lf->fold( '' , ' ' x $s_tab, $pr_key . $info->{$ex}{$video_id}{$key} );
+        my $text = line_fold(
+            $pr_key . $info->{$ex}{$video_id}{$key},
+            $col_max,
+            '' , ' ' x $s_tab
+        );
         $text =~ s/\R+\z//;
         push @$print_array, map { "$_\n" } split /\R+/, $text;
     }
@@ -92,26 +94,32 @@ sub linefolded_print_info {
     }
     if ( $plus ) {
         $col_max += $plus;
-        $lf->config( 'ColMax', $col_max );
         $print_array = [];
         for my $key ( @keys ) {
             next if ! length $info->{$ex}{$video_id}{$key};
             ( my $kk = $key ) =~ s/_/ /g;
             my $pr_key = sprintf "%*.*s : ", $key_len, $key_len, $kk;
-            my $text = $lf->fold( '' , ' ' x $s_tab, $pr_key . $info->{$ex}{$video_id}{$key} );
+            my $text = line_fold(
+                $pr_key . $info->{$ex}{$video_id}{$key},
+                $col_max,
+                '' , ' ' x $s_tab
+            );
             $text =~ s/\R+\z//;
             push @$print_array, map { "$_\n" } split /\R+/, $text;
         }
     }
     if ( @$print_array > ( $maxrows - 6 ) ) {
         $col_max = $maxcols;
-        $lf->config( 'ColMax', $col_max );
         $print_array = [];
         for my $key ( @keys ) {
             next if ! length $info->{$ex}{$video_id}{$key};
             ( my $kk = $key ) =~ s/_/ /g;
             my $pr_key = sprintf "%*.*s : ", $key_len, $key_len, $kk;
-            my $text = $lf->fold( '' , ' ' x $s_tab, $pr_key . $info->{$ex}{$video_id}{$key} );
+            my $text = line_fold(
+                $pr_key . $info->{$ex}{$video_id}{$key},
+                $col_max,
+                '' , ' ' x $s_tab
+            );
             $text =~ s/\R+\z//;
             push @$print_array, map { "$_\n" } split /\R+/, $text;
         }
