@@ -13,9 +13,9 @@ use File::Temp            qw();
 use FindBin               qw( $RealBin $RealScript );
 use Pod::Usage            qw( pod2usage );
 
-use Term::Choose           qw( choose );
-use Term::Choose::Util     qw( print_hash choose_a_dir choose_a_number settings_menu insert_sep );
-use Term::ReadLine::Simple qw();
+use Term::Choose       qw( choose );
+use Term::Choose::Util qw( print_hash choose_a_dir choose_a_number settings_menu insert_sep );
+use Term::Form         qw();
 
 use if $^O eq 'MSWin32', 'Win32::Console::ANSI';
 
@@ -182,7 +182,8 @@ sub set_options {
         next if $group eq 'main';
         push @keys, grep { ! /^_/ } map { $_->[0] } @{$menus->{$group}};
     }
-    for my $key ( %$sub_menus ) {
+    #for my $key ( %$sub_menus ) {
+    for my $key ( keys %$sub_menus ) {
         push @keys, map { $_->[0] } @{$sub_menus->{$key}};
     }
     my $group = 'main';
@@ -499,7 +500,7 @@ sub _opt_choose_a_directory {
 
 sub _local_readline {
     my ( $opt, $section, $prompt, $list ) = @_;
-    my $trs = Term::ReadLine::Simple->new();
+    my $trs = Term::Form->new();
     my $new_list = $trs->fill_form(
         $list,
         { prompt => $prompt, auto_up => 2, confirm => '  CONFIRM', back => '  BACK' }
